==> schorg-0.5.0-py2.py3-none-any.whl: schorg/HowToItem.py <==
"""
An item used as either a tool or supply when performing the instructions for how to achieve a result.

https://schema.org/HowToItem
"""

from typing import *
from typing_extensions import TypedDict, NotRequired
from pydantic import *
from datetime import *
from time import *


from schorg.schema_org_obj import SchemaOrgObj, SchemaOrgBase


class HowToItemInheritedProperties(TypedDict):
    """An item used as either a tool or supply when performing the instructions for how to achieve a result.

    References:
        https://schema.org/HowToItem
    Note:
        Model Depth 4
    Attributes:
        item: (Optional[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]): An entity represented by an entry in a list or data feed (e.g. an 'artist' in a list of 'artists').
        nextItem: (Optional[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]): A link to the ListItem that follows the current one.
        previousItem: (Optional[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]): A link to the ListItem that precedes the current one.
        position: (Optional[Union[List[Union[SchemaOrgObj, int, str]], SchemaOrgObj, int, str]]): The position of an item in a series or sequence of items.
    """

    item: NotRequired[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]
    nextItem: NotRequired[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]
    previousItem: NotRequired[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]
    position: NotRequired[Union[List[Union[SchemaOrgObj, int, str]], SchemaOrgObj, int, str]]
    


class HowToItemProperties(TypedDict):
    """An item used as either a tool or supply when performing the instructions for how to achieve a result.

    References:
        https://schema.org/HowToItem
    Note:
        Model Depth 4
    Attributes:
        requiredQuantity: (Optional[Union[List[Union[SchemaOrgObj, str, StrictInt, StrictFloat]], SchemaOrgObj, str, StrictInt, StrictFloat]]): The required quantity of the item(s).
    """

    requiredQuantity: NotRequired[Union[List[Union[SchemaOrgObj, str, StrictInt, StrictFloat]], SchemaOrgObj, str, StrictInt, StrictFloat]]
    

#HowToItemInheritedPropertiesTd = HowToItemInheritedProperties()
#HowToItemPropertiesTd = HowToItemProperties()


class AllProperties(HowToItemInheritedProperties , HowToItemProperties, TypedDict):
    pass


def create_schema_org_model(type_: Union[HowToItemProperties, HowToItemInheritedProperties, AllProperties] = AllProperties) -> Type[SchemaOrgBase]:
    model = create_model_from_typeddict(type_, __base__=SchemaOrgBase)
    model.__name__ = "HowToItem"
    return model
    

HowToItem = create_schema_org_model()

==> schorg-0.7.0-py2.py3-none-any.whl: schorg/HowToItem.py <==
"""
An item used as either a tool or supply when performing the instructions for how to achieve a result.

https://schema.org/HowToItem
"""

from typing import *
from typing_extensions import TypedDict, NotRequired
from pydantic import *
from datetime import *
from time import *


from schorg.schema_org_obj import SchemaOrgObj, SchemaOrgBase


class HowToItemInheritedProperties(TypedDict):
    """An item used as either a tool or supply when performing the instructions for how to achieve a result.

    References:
        https://schema.org/HowToItem
    Note:
        Model Depth 4
    Attributes:
        item: (Optional[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]): An entity represented by an entry in a list or data feed (e.g. an 'artist' in a list of 'artists').
        nextItem: (Optional[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]): A link to the ListItem that follows the current one.
        previousItem: (Optional[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]): A link to the ListItem that precedes the current one.
        position: (Optional[Union[List[Union[SchemaOrgObj, str, int]], SchemaOrgObj, str, int]]): The position of an item in a series or sequence of items.
    """

    item: NotRequired[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]
    nextItem: NotRequired[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]
    previousItem: NotRequired[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]
    position: NotRequired[Union[List[Union[SchemaOrgObj, str, int]], SchemaOrgObj, str, int]]
    


class HowToItemProperties(TypedDict):
    """An item used as either a tool or supply when performing the instructions for how to achieve a result.

    References:
        https://schema.org/HowToItem
    Note:
        Model Depth 4
    Attributes:
        requiredQuantity: (Optional[Union[List[Union[SchemaOrgObj, str, StrictInt, StrictFloat]], SchemaOrgObj, str, StrictInt, StrictFloat]]): The required quantity of the item(s).
    """

    requiredQuantity: NotRequired[Union[List[Union[SchemaOrgObj, str, StrictInt, StrictFloat]], SchemaOrgObj, str, StrictInt, StrictFloat]]
    


class AllProperties(HowToItemInheritedProperties , HowToItemProperties, TypedDict):
    pass


class HowToItemBaseModel(SchemaOrgBase):
    id_ : Optional[Any] = Field(default="HowToItem",alias='@id')
    context_ : Optional[Any] = Field(default=None,alias='@context')
    graph_ : Optional[Any] = Field(default=None,alias='@graph')

    class Config:
        
        fields = {'item': {'exclude': True}}
        fields = {'nextItem': {'exclude': True}}
        fields = {'previousItem': {'exclude': True}}
        fields = {'position': {'exclude': True}}
        fields = {'requiredQuantity': {'exclude': True}}
        


def create_schema_org_model(type_: Union[HowToItemProperties, HowToItemInheritedProperties, AllProperties] = AllProperties) -> Type[SchemaOrgBase]:
    model = create_model_from_typeddict(type_, __base__=SchemaOrgBase)
    model.__name__ = "HowToItem"
    return model
    

HowToItem = create_schema_org_model()


def create_howtoitem_model(model: AllProperties):
    _type =  AllProperties.copy()
    for k in model.keys():
        if k not in _type.__annotations__:
            del _type.__annotations__[k]
    return create_schema_org_model(type_=_type)


def schema_json(model: AllProperties):
    pydantic_type =  create_howtoitem_model(model=model)
    return pydantic_type(model).schema_json()
